function String = Alphabet(Qualifier,Type)
%
%   Alphabet
%   -----------------------------------------------------------------------
%
%   Obtain characters according to qualitative marker (-3 to 3). The vector
%   of integers is converted into a string.
%
%   I/O: String = Alphabet(qualifier,type)
%
%   inputs:
%       Qualifier:  [optional] vector of qualitative markers for episodes,
%                   as integers ranging from -3 to 3. If left unspecified,
%                   complete alphabet is returned.
%       Type:       [optional] specify whether monotonic or triangular
%                   primitives are used. Use 1 for monotonic, 2 for
%                   triangular. [default=2]    
%
%   outputs:
%       String:     String consisting of characters corresponding to
%                   qualitative markers
%
%   Originally by:      Kris Villez, 03/10/2010
%   Last update by:     Kris Villez, 31/10/2010
%
%   -----------------------------------------------------------------------
%

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

if nargin<1 || isempty(Qualifier),  Qualifier   =   1:14    ;   end % get complete map
if nargin<2 || isempty(Type),       Type        =   3       ;   end % unspecified type, then use triangular primitives

% verify whether qualifiers are proper
%assert(all(Qualifier(:)>=-3),'At least one qualifier too low (mimimally: -3')
%assert(all(Qualifier(:)<=3),'At least one qualifier too high (maximally: +3')

% verify whether specified type is proper

if Type == 1,       Characters  =   'LLLFUUULFUQQQQ'     ;   % Signs first derivative: L:- / F:0 / U:+
elseif Type == 2,   Characters  =   'NOPONOPQQQNOPQ' ;   % Signs second derivative: L:- / F:0 / U:+
else                Characters  =   'DEAFCGBLFUNOPQ'   ;   % Signs derivatives: B:-- / E:-0 / C:-+ / F:00 / A:+- / G:+0 / D:++ 
end

String      =   Characters(Qualifier)       ;   % get corresponding characters
