function nodisc = AnyDisc(SCS) 

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - Boundlow.m
%
% This function evaluates whether there are any discontinuities implied by
% the QR.
%
% Syntax:
%   nodisc = AnyDisc(SCS) 
%
% Inputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%
% Outputs:
%   nodisc  :   boolean indicating whether all transitions are continuous
%                   or not
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-20
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

if isfield(SCS,'series')
    
    m = SCS.m ;
    
    for s=1:m
        qr          =   SCS.series{s}.qr  ;
        disc        =   qr(6,:)             ;
        nodisc(s)   =   ~any(disc)          ;
    end
    nodisc          =   any(nodisc)         ;
else
    nodisc = true;
end