function SCS   =   AssessVerifiability(SCS,IntX) 

% -------------------------------------------------------------------------
% SCS toolbox - AssessVerifiability.m
%
% This function evaluates whether particular transitions in a QR can be
% found with zero precision thanks to shape verification.
% 
% Syntax:
%	SCS   =   AssessVerifiability(SCS,IntX) 
%
% Inputs: 	
%	SCS 	: Structure defining Shape Constrained Spline			
%   IntX 	: Interval bounds for transitions
% Outputs: 	
%   SCS		: Updated SCS (added/updated field 'verifiable')
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-20
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

m   =   size(IntX,2)  ;
counts  =   zeros(m,1)  ;
verifiable  =   false(m,1)  ;

QRs =   SCS.QR  ;
V =1;

QR      =   QRs{1}          ;
m       =   size(QR,2)-1    ;
QRmap{1}=   1:m             ;

for v=1:V
%     QRmap{v}
    counts(QRmap{v})    =   counts(QRmap{v})+1;
%     counts
    QR  =   QRs{v}  ;
    m = size(QR,2)-1 ;
    for j=1:m
        if QR(end,j)==0
            r = 5 ;
            if and(~isnan(QR(r,j)),~isnan(QR(r,j+1))) % defined second derivative
                if QR(r,j)~=QR(r,j+1) % change in second derivative)
                    verifiable(QRmap{v}(j)) =   1;
                else % no change in second derivative
                    r = 4 ;
                    if and(~isnan(QR(r,j)),~isnan(QR(r,j+1))) % defined first derivative
                        if QR(r,j)~=QR(r,j+1) % change in first derivative)
                            verifiable(QRmap{v}(j)) =   1;
                        else % no change in first derivative
                            r = 3 ;
                            if and(~isnan(QR(r,j)),~isnan(QR(r,j+1))) % defined function sign
                                if QR(r,j)~=QR(r,j+1) % change in function sign)
                                    verifiable(QRmap{v}(j)) =   1;
                                else % no change in first derivative
                                    disp('no changes at all!')
                                end
                            end
                        end
                    end
                end
            end
        end
    end
end

SCS.verifiable = verifiable ;