function [LB,SCS]   =   BoundlowSCS(SCS,IntX)  

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - Boundlow.m
%
% This function computes the lower bound SCS fit.
%
% Syntax:
%   [LB,SCS]   =   Boundlow(SCS,IntX)   
%
% Inputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%   IntX    :   Polyhedral set of transitions
%
% Outputs:
%   LB      :   lower bound objective value
%   SCS     :   [optional] relaxed Shape Constrained Spline fit
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-21
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

PriorLB   =   PriorBounds(IntX,SCS)    ;
% -------------------------------------------------------------------------
% 0. adjust time interval where necessary
% make sure proposed episode bounds are within argument range of Bspline
% function:
tk      =   SCS.tk      ;   % knot argument locations
tk      =   tk(:)       ;   %   as column vector

% IntX =   Knots2Times(IntX,tk)       ;    
IntX =   min(max(IntX,tk(1)),tk(end)) ;   
% -------------------------------------------------------------------------
% 1. update qualitative representation (QR)
QRs     =   SCS.QR      ;
V       =   length(QRs) ;
if V>1
	error('Unsupported functionality - Only one QR allowed')
else
    v = 1;
    QR  =   QRs{v}  ;
    signs   =   QR(3:5,:)   ;
    disc    =   QR(6,:)     ;
    QR      =   [   tk(1)         IntX(2,:)    ;
        IntX(1,:)  tk(end)         ;
        signs                         ;
        disc                          ];
    QRs{v}  =   QR ;
end
% QR
SCS.QR  =   QRs ;
% -----------------------------------------------
% 2. evaluate fit
SCS     =   SCS.FitFun(SCS) ;

% Re-add original QR because FitSCS manipulates and stores adjusted QR!
% This is especially important if using 'verify' option in the BNB
% algorithm implementation (function VerifyShape.m)
SCS.QR  =   QRs ;
% -----------------------------------------------
% 3. obtain upper bound
LB      =   SCS.J       ; %  update reported SCS

LB                  =   LB + PriorLB                ;
return