function Colour  =   CFD(Qualifier,Map)
%
%   CFD (Colours For Drawing) 
%   -----------------------------------------------------------------------
%
%   Obtain RGB colour codes corresponding to qualitative markers
%
%   I/O: Colour  =   CFD(index,Map)
%
%   inputs:
%       Qualifier:  [optional] vector of qualitative markers for episodes,
%                   as integers ranging from -3 to 3. If left unspecified,
%                   complete colour map is returned.
%       Map:        [optional] Colour map used. Use 1 for colour map
%                   (blue/red tones), use 2 for grey scale map.
%                   [default=1]    
%
%   outputs:
%       Colour:     Matrix of RGB colours for each element in Qualifier.
%                   Each of three columns represents one channel (RGB).
%
%   Originally by:      Kris Villez, 28/11/2009
%   Last update by:     Kris Villez, 20/05/2010
%
%   -----------------------------------------------------------------------
%

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

if nargin<1 || isempty(Qualifier),  Qualifier   =   (1:7)  ;   end % get complete map
if nargin<2 || isempty(Map),        Map         =   1       ;   end % unspecified map, use colour one

% verify whether qualifier are proper
%assert(all(Qualifier(:)>=-3),'At least one qualifier too low (mimimally: -3')
%assert(all(Qualifier(:)<=3),'At least one qualifier too high (maximally: +3')

switch Map
    case 1
        % colour map
        Colour   =   [  0   0   1   ;
                        0   0   .8  ;
                        0   0   .3  ;
                        0   0   0   ;
                        1   0   0   ;
                        .8  0   0   ;
                        .3  0   0   ;
                        0   0   .8  ;
                        0   0   0   ;
                        .8  0   0   ;
                        0   .5  .5  ;
                        0   0   0   ;
                        .5  .5  0   ;
                        1   1   1   ]   ;
    case 2
        % grey scale map
        Colour   =   [   5/7 2/7 1/7 4/7 7/7 6/7 3/7 ]'/2   ;
        Colour   =       mean(Colour,2)*ones(1,3)           ;
    otherwise
        error('unknown map')
end

Colour      =   Colour(Qualifier,:) ;   % get corresponding RGB colours
