function DistX = DefaultDistX(SCS) 

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - DefaultDistX.m
%
% This function computes the default distance constraints on the
% transitions.
%
% Syntax:
%   DistX = DefaultDistX(SCS) 
%
% Inputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%
% Outputs:
%   DistX   :   Default distance contraints for transitions
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-20
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

tk      =   SCS.tk          ;
t1      =   SCS.tk(1)       ;
t2      =   SCS.tk(end)     ;

nQR = size(SCS.QR{1},2);
DistX(2,:)    =   ( t2-t1 )*ones(1,nQR-2)  ;
DistX(1,:)    =    min(tk(2:end)-tk(1:end-1));
