function [p] = EvalPoly(SCS,deriv,x)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - EvalPoly.m
%
% This function evaluites the roots of the shape constrained spline
% function or its derivative
%
% Syntax:
%   Roots = EvalRoots(SCS,deriv,x)
%
% Inputs:
%   SCS         :   structure describing the Shape Constrained Spline
%                   function. 
%   deriv       :   number of the derivative (0 = function itself)
%   x           :   spline coefficients
%
% Outputs:
%   p           :   polynomial coefficients of the spline function or its
%                   derivative 
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-20
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

        if nargin<2 || isempty(deriv),  deriv  = 0      ;   end % by default, evaluate function value

        if nargin<3 || isempty(x)
            x   =   SCS.x  ;
        end
        
        nx      =   length(x)   ;
        tk      =   SCS.tk     ;
        
        for ix=1:nx
            X2P     =   SCS.X2P{end-deriv,ix}   ;
            [m,n]   =   size(X2P{1})            ;
            np      =   length(X2P)         ;
        
            p   =   nan(m,np);
            for ip=1:np
                p(:,ip)    =   X2P{ip}*x{ix}   ;
            end
        end
