function Roots = EvalRoots(SCS,deriv,x)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - EvalRoots.m
%
% This function evaluites the roots of the shape constrained spline
% function or its derivative
%
% Syntax:
%   Roots = EvalRoots(SCS,deriv,x)
%
% Inputs:
%   SCS         :   structure describing the Shape Constrained Spline
%                   function. 
%   deriv       :   number of the derivative (0 = function itself)
%   x           :   spline coefficients
%
% Outputs:
%   Roots       :   root locations of the spline function or its derivative
%
% -------------------------------------------------------------------------
% Latest version: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

graph = 0;

% find piece-wise polynomial representation
[p] = EvalPoly(SCS,deriv,x);

Roots  =   []  ;
for i=1:size(p,1)
    r       =       roots(p(i,:))           ;
    r       =       r(and(r>=0,r<=1))       ;
    r       =       r(abs(imag(r))<eps)     ;
    r       =       real(r)+i-1             ;
    Roots   =   [   Roots ;   r(:)    ]     ;
    if graph
        to      =       0:.1:1                  ;
        yo      =       polyval(p(i,:),to)      ;
        plot(to+i-1,yo,'m--')
        PlotVertical(r,'k--')
    end
end

if graph
    PlotVertical(Roots,'k--')
end

% pause