function [Z,B] = EvalSCS(SCS,tx,d)

% -------------------------------------------------------------------------
% SCS toolbox - EvalSCS.m
%
% Evaluate shape constrained spline function or one of its derivatives
% 
% Syntax is as follows:
%   [Z,B] = EvalSCS(SCS,tx,d)
%
% Inputs: 	
%   SCS :   Structure defining Shape Constrained Spline
% 	tx  :   [optional] spline arguments in which SCS function evaluation
%               is requested. 
%           [default] data arguments 
% 	d   :   [optional] computed derivative number. 
%           [default] 0 (function value)
% Outputs: 	
%   Z   :   computed function/derivative (column vector)
%   B   :   [optional] basis matrix to compute function/derivative
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-06-13
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

if isnumeric(SCS)
    B   =   SCS ;
    x   =   tx  ;
    Z   =   B*x ; % evaluate function or derivative
else
    
    if nargin<3 || isempty(d),  d  = 0      ;   end % by default, evaluate function value
    if nargin<2 || isempty(tx),     tx     = SCS.ty ;   end % by default, use observation locations
    if iscell(SCS.x)
        basis   =   SCS.bases{1}                   ; % get basis
        x       =   SCS.x{1}                       ; % get coefficients
    else
        %                 basis   =   SCS.bases{1}                   ; % get basis
        basis   =   SCS.basis                   ; % get basis
        x       =   SCS.x                      ; % get coefficients
    end
    %             basis
    B       =   eval_basis(tx,basis,d)  ; % obtained required basis for specified coefficients and derivative d
    Z 		=   B*x                         ; % evaluate function or derivative
    
end
