function QR  =   ExpandQR(QR) 

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - ExpandQR.m
%
% This function expands the QR so to have a contiguous set of episodes
%
% Syntax:
%   QR  =   ExpandQR(QR) 
%
% Inputs:
%   QR        :   Qualitative Representation 
%
% Outputs:
%   QR        :   Qualitative Representation (without contiguous episodes)
%
% -------------------------------------------------------------------------
% Latest version: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------


C   =   size(QR,2)  ;

for c=C-1:-1:1    
    tL =    QR(2,c)     ;   % left
    tR =    QR(1,c+1)   ;   % right
    if tL<tR    % gap is present
        SignL   =   QR(3:5,c)                       ;
        SignR   =   QR(3:5,c+1)                     ;
        loc1    =   find(and(SignL ==0,~isnan(SignR)))  ;
        SignL(loc1) =   SignR(loc1) ;
        SignR(loc1) =   SignL(loc1) ;
        loc1    =   find(and(SignR ==0,~isnan(SignL)))  ;
        SignL(loc1) =   SignR(loc1) ;
        SignR(loc1) =   SignL(loc1) ;
        Same    =   and(SignL==SignR,~isnan(SignL)) ;
        if any(Same)
            SignM       =   nan(1,3)                            ;
            SignM(Same) =   SignL(Same)                         ;
            qr          =   [   tL tR SignM nan ]'              ;
            QR          =   [   QR(:,1:c) qr  QR(:,c+1:end) ]   ;
        end
    end 
end
