function [trans,QR] = FindTransitions(SCS)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - FindTransitions.m
%
% This function computes the transition locations with absolute precision
% whereever possible.
%
% Syntax:
%   [trans,QR] = FindTransitions(SCS) 
%
% Inputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%
% Outputs:
%   trans   :   transition locations
%   QR      :   [optional] updated Qualitative Representation
%
% -------------------------------------------------------------------------
% Latest version: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

QR = SCS.QR ;

nQ  =   size(QR,2) ;

ty  =   SCS.ty ;
for d=0:2
    y{d+1} = EvalSCS(SCS,ty,d);
end

trans = QR(1,2:end) ;
for iQ=nQ-1:-1:1 % run backwards because QR can be expanded in certain cases
    t1  =   QR(2,iQ);
    t2  =   QR(1,iQ+1);
    s0  =   QR(3,iQ:iQ+1)   ;
    s1  =   QR(4,iQ:iQ+1)   ;
    s2  =   QR(5,iQ:iQ+1)   ;
    
    if t1==t2
        %disp('equal')
        trans(iQ) = t1 ;
    else
%         disp('not equal')
       
        if ~all(isnan(s2)) && s2(1)~=s2(2)
            disp('inflection point')
            inc =   find(and(t1<=ty,ty<=t2)) ;
            y1  =   y{1+1} ;
            y1  =   y1{1} ;
%             figure, plot(ty(inc),y1(inc),'.')
            
            if and(s2(1)==+1,s2(2)==-1)
                [oo,loc] = max(y1(inc));
                trans(iQ) = ty(inc(loc)) ;
            elseif and(s2(1)==-1,s2(2)==+1)
                [oo,loc] = min(y1(inc));
                trans(iQ) = ty(inc(loc)) ;
            else
                trans(iQ) = nan ;
             %   disp('warning: unknown condition')
            end
        elseif ~all(isnan(s1)) && s1(1)~=s1(2)
            disp('extremum')
            inc =   find(and(t1<=ty,ty<=t2)) ;
            if and(s1(1)==1,and(s2(1)==+1,s2(2)==+1))
%                 disp('maximum w inflections')
                addtrans = zeros(1,3) ;
                % find maximum first
                inc =   find(and(t1<=ty,ty<=t2)) ;
                
                y0  =   y{0+1} ;
                y1  =   y{1+1} ;
                %figure, plot(ty(inc),y0(inc),'.')

                
                if and(s1(1)==+1,s1(2)==-1)
                    [oo,loc] = max(y0(inc));
                    addtrans(3) = ty(inc(loc)) ;
                else
                    addtrans(3) = nan ;
                   % disp('warning: unknown condition')
                end
%                 addtrans(2)
                
                for j=1:2
                    if j==1
                        inc =   find(and(t1<=ty,ty<=addtrans(3))) ;
                    else
                        inc =   find(and(addtrans(3)<=ty,ty<=t2)) ;
                    end 
                    
                    if and(s2(1)==+1,j==1)
                        [oo,loc] = max(y1(inc));
                        addtrans(j) = ty(inc(loc)) ;
                    elseif and(s2(1)==+1,j==2)
                        [oo,loc] = min(y1(inc));
                        addtrans(j) = ty(inc(loc)) ;
                    else
                        addtrans(j) = nan ;
                      %  disp('warning: unknown condition')
                    end
                end
                addtrans    =       sort(addtrans)  ;
                
                addQR       =       zeros(6,2)      ;
                addQR(:,1)  =       QR(:,iQ)        ;
                addQR(:,2)  =       QR(:,iQ+1)      ;
                addQR(5,:)  =       -addQR(5,:)     ;
                QR          =   [   QR(:,1:iQ) addQR QR(:,iQ+1:end)  ];
                trans       =   [   trans(1:iQ-1) addtrans trans(iQ+1:end) ];
                
            else
                %disp('warning: undeveloped condition')
            end
            
        elseif ~all(isnan(s0)) && s0(1)~=s0(2)
            %disp('warning: undeveloped condition')
            trans(iQ) = nan ;
            
        else
            %disp('warning: unknown condition')
        end
    end
    
end