function [a,b,Maps,m,meq,ss,kki,kke] = GetMaps(SCS,int,d,n)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - GetMaps.m
%
% This function processes constraint intervals into specific constraint
% information.
%
% Syntax:
%   [J,Fit,Pen]   =   L2L2(x,SCS)
%
% Inputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%   int     :   interval specifications
%   d       :   derivative number
%   n       :   order of spline function
%
% Outputs:
%   a,b     :   interval endpoints for shape constraints
%   Maps    :   projection matrices (spline coefficients to polynomial
%                   coefficients)
%   m       :   number of inequality constrained intervals
%   meq     :   number of equality constrained intervals
%   ss      :   signs for inequality constrained intervals
%   kki     :   associated knot interval for inequality constrained
%                   intervals
%   kke     :   associated knot interval for equality constrained intervals
%
% -------------------------------------------------------------------------
% Latest version: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

[intineq,inteq,m,meq]   =   SplitInt(int)  ;

R       =   n-d         ;
C       =   2           ;
Maps    =   cell(R,C)   ;

for c=1:C
    switch c
        case 1
            int =   intineq     ;
            a   =   int(:,4)	;
            b   =   int(:,5)    ;
            kki =   int(:,3)    ;
            ss  =   int(:,6)        ;
        case 2
            int =   inteq   ;
            kke =   int(:,3)    ;
    end
    
    if ~isempty(int)
        MapX2P 	=   SCS.X2P{n-d}	;
        kk      =   int(:,3)        ;
        ss      =   int(:,6)        ;
        for r=1:n-d
            Map         =   MapX2P{r}               ;
            Maps{r,c}   =   diag(ss.^ss)*Map(kk,:)  ;
        end
    else
        for r=1:n-d
            Maps{r,c}   =   []  ;
        end
    end
end