function MapX2P  =   GetMapsX2P(a,Bk,d,n)
 
% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - GetMapsX2P.m
%
% This function evaluates the matrices which project the spline
% coefficients to the polynomial coefficients
%
% Syntax:
%   MapX2P  =   GetMapsX2P(a,Bk,d,n)
%
% Inputs:
%   a         :   argument intervals
%   Bk        :   basis matrices for function and its derivatives
%   d         :   derivative degree (0=function itself)
%   n         :   order of  the spline function
%
% Outputs:
%   MapX2P      :   Projection matrices
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-20
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

% a: knot location
% d: degree of derivative for which polynomial is computed
% n: degree of spline function

da      =   a(2:end)-a(1:end-1) ;
cc      =   0:n-d-1             ;
MapX2P  =   cell(n-d,1)         ;

for c=cc % 0 .. 3
    B           =   Bk{end-c}     ; % n-c: 4 .. 1
    MapX2P{c+1} =   1./factorial(n-d-c-1) *diag(da.^(n-d-c-1)) *B(1:end-1,:)    ;
end

