function [Bineq,Beq] =   GetPointConstraints(SCS)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - GetPointConstraints.m
%
% This function computes projection matrices for point-wise inequality and
% equality constraints
%
% Syntax:
%   [Bineq,Beq] =   GetPointConstraints(SCS)
%
% Inputs:
%   SCS     :   structure describing a Shape Constrained Spline function.
%
% Outputs:
%   Bineq   :   projection matrix for point-wise inequality constraints
%   Beq     :   projection matrix for point-wise equality constraints
%
% -------------------------------------------------------------------------
% Latest version: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

order   =   SCS.order  ;
QR      =   SCS.QR                 ;
inc     =   find(or(QR(1,:)==QR(2,:),~or(isnan(QR(4,:)),isnan(QR(5,:)))))  ;
QR      =   QR(:,inc)               ;
nQ      =   size(QR,2)              ;

tt      =   QR(1,:)'                ;
te      =   sort([ SCS.tk ; tt ])  ;

nx      =   length(SCS.x{1})  ;
Beq     =   zeros(0,nx)     ;
Bineq   =   zeros(0,nx)     ;

for d=0:min(order-1,2)
    qr  =   QR(d+3,:)   ;
    if any(~isnan(qr))
        [oo,B]  =   EvalSCS(SCS,te,d)  ;
        for iQ=1:nQ
            rows    =   find(and(te>=QR(1,iQ),te<=QR(2,iQ))) ;
            switch qr(iQ)
                case 0
                    Beq     =   [   Beq     ;   B(rows,:)   ]   ;
                case {1,-1}
                    Bineq   =   [   Bineq   ;   qr(iQ)*B(rows,:)   ]   ;
            end
        end
    end
end
