function [J,Fit,Pen]   =   L2L2(x,SCS)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - L2L2.m
%
% This function computes a regularized fit objective with both fit and
% regularization as quadratic terms. 
%
% Syntax:
%   [J,Fit,Pen]   =   L2L2(x,SCS)
%
% Inputs:
%   x   :   Spline coefficients
%   SCS	:   Structure describing the Shape Constrained Spline function
%
% Outputs:
%   J   :   Objective function
%   Fit :   Objective term due to lack-of-fit
%   Pen :   Objective term due to regularization
%
% -------------------------------------------------------------------------
% Latest version: Kris Villez, 2013-06-23
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

X   =   x               ;
Y   =   SCS.y           ;
B0t =   SCS.B0y{1}      ;
L   =   SCS.L{1}        ;

Fit =   (norm(Y-B0t*X)).^2  ;
Pen =   X'*L*X                      ;
J   =   Fit+Pen                   ;   % total objective
