function [J,Fit,Pen]   =   L2L2cvx(x,SCS)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - L2L2cvx.m
%
% This function computes a regularized fit objective with both fit and
% regularization as quadratic terms. This version is used for the cvx based
% SOCP solution.
%
% Syntax:
%   [J,Fit,Pen]   =   L2L2cvx(x,SCS)
%
% Inputs:
%   x   :   Spline coefficients
%   SCS	:   Structure describing the Shape Constrained Spline function.
%
% Outputs:
%   J   :   Objective function
%   Fit :   Objective term due to lack-of-fit
%   Pen :   Objective term due to regularization
%
% -------------------------------------------------------------------------
% Latest version: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

% this function computes a regularized fit objective with both fit and
% regularization as quadratic terms. This is done in a way that cvx can be
% used for optimization

X   =   x               ;
Y   =   SCS.y(:)        ;
B0t =   SCS.B0y{1}      ;
L   =   SCS.L{1}        ;

Fit =   pow_pos((norm(Y-B0t*X)),2)  ;
Pen =   X'*L*X                      ;
J   =   Fit+Pen                     ;   % total objective