function han = PlotSCS(SCS,tx)

% -------------------------------------------------------------------------
% SCS toolbox - FitSCS.m
%
% Plots Shape Constrained Spline function and derivatives
% 
% Syntax is as follows:
%   han = FitSCS(SCS,tx)
%
% Inputs: 	
%   SCS :   Structure defining Shape Constrained Spline
%   tx  :   [optional] spline function arguments
%           [default] knot locations
% Outputs: 	
%   han :   Subplot handles
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-20
% -------------------------------------------------------------------------


% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

type = 2;
plotstr  =   {'kx-','kx-'} ;
plotstr1 =   {'k-','k-'} ;
plotstr2 =   {'kx','kx'} ;

ty      =   SCS.ty  ;   % data time vector
Y       =   SCS.y   ;   % data observation vector
X       =   SCS.x   ;   % spline coefficients

if ~iscell(X)
    X   =   {X} ;
    oldstyle  = 1;
else
    oldstyle  = 0;
end
V  =   length(X)     ;

switch type
    case 1
        figure,
        FigPrep
        SUB = 2;
        
    case 2
        figure,
        FigPrep
        SUB = 2 ;%max(SCS.order);
end

for v=1:V
    x   =   X{v}        ;
    y   =   Y(:,v)      ;
    
    tk      =   SCS.tk      ;
    if nargin<2 % if no vector is supplied, use
        % knot-evaluated basis
        tx      =   tk      ;
    end      % else evaluate basis in provided locations
    
    % evaluate function and derivatives in specified locations
    nk      =   length(tk)      ;
    nx      =   length(tx)      ;
    Zk      =    zeros(nk,SUB)     ;
    Zx      =   zeros(nx,SUB)     ;
    
    if oldstyle
        basis   =   SCS.basis  ;
        order   =   SCS.order  ;
        B0y     =   SCS.B0y    ;
    else
        basis   =   SCS.bases{v}   ;
        order   =   SCS.order(v)  ;
        B0y     =   SCS.B0y{v}     ;
    end
    for j=0:order-1
        Bk          =   eval_basis(tk,basis,j)    ;
        Zk(:,j+1)   =   Bk*x(:)        ;
        Bx          =   eval_basis(tx,basis,j)    ;
        Zx(:,j+1)   =   Bx*x(:)        ;
    end
    % % evaluate function in observation arguments
    Z0y     =   B0y*x  ;
    
    % end
    
    
    
    % =========================================================================
    % PLOTTING
    LW      = 2     ; % line width
    
    switch type
        case 1
            han = nan(2,1) ;
            sub = 1;
            han(sub) = subplot(SUB,1,sub);
            hold on
            plot(ty,y,      'ko',   'Linewidth', LW )
            plot(ty,Z0y,  plotstr1{v},  'Linewidth', LW )
            %PlotHorizontal(0,'k-')
            axis tight
            set(gca,'Xlim',[ty(1) ty(end)])
            sub=2;
            han(sub) = subplot(SUB,1,sub);
            hold on
            plot(ty,Z0y-y,      plotstr1{v},   'Linewidth', LW )
            %PlotHorizontal(0,'k-')
            axis tight
            set(gca,'Xlim',[ty(1) ty(end)])
        case 2
            
            han = nan(SUB,1) ;
            for sub=1:SUB
                
                han(sub) = subplot(SUB,1,sub);
                AxisPrep
                hold on
                if sub==1
                    plot(ty,y,      'ko',   'Linewidth', LW )
                end
                plot(tx(1),Zx(1,sub), plotstr{v},  'Linewidth', LW,'MarkerSize',10 )
                plot(tx,Zx(:,sub), plotstr1{v},  'Linewidth', LW,'MarkerSize',10)
                plot(tk,Zk(:,sub), plotstr2{v},  'Linewidth', LW,'MarkerSize',10 )
                if sub==1
                    legend({'data','spline function'},2)
                    ylabel('y')
                    title('Fitted spline')
                elseif sub==2
                    ylabel({'dy/dx'})
                else
                    ylabel({['d^' num2str(sub-1) 'y/dx^' num2str(sub-1)  ]})
                end
                %                 plot((1:length(Zx(:,sub)))-2,Zx(:,sub), plotstr{v},  'Linewidth', LW )
                %             plot(tx,Zx(:,sub)+StdX(:,sub),  'b--',  'Linewidth', LW )
                %             plot(tx,Zx(:,sub)-StdX(:,sub),  'b--',  'Linewidth', LW )
                %         end
                %   PlotHorizontal(0,'k-')
                axis tight
                set(gca,'Xlim',[ty(1) ty(end)])
                %     end
            end
    end
    
        
        
    drawnow
end