function SCS	= Presolve(SCS)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - Presolve.m
%
% This function computes the unconstrained spline fit, i.e., taking only
% lack-of-fit and regularization objectives into account and ignoring any
% shape constraints.
%
% Syntax:
%   SCS	= Presolve(SCS)
%
% Inputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%
% Outputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%                   with uncosntrained solution
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-06-06
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

B       =   sparse(SCS.B0y{1})          ;
L       =   sparse(SCS.L{1})            ;
P       =   (B'*B+L)^(-1)*B'    ;
SCS.P   =   P                   ;
y       =   SCS.y               ;
x       =   P*y                 ;
W1      =   P*P'                ;
W       =   inv(W1)             ;
% W       =   (W+W')/2            ;

SCS.presolve.x{1}   =   x   ;
SCS.presolve.W{1}   =   W   ;