function [QR,trans] = SCS2QR(SCS)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - SCS2QR.m
%
% This function computes the Triangular Qualitative Representation for
% vizualization.
%
% Syntax:
%   [QR,trans] = SCS2QR(SCS) 
%
% Inputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%
% Outputs:
%   QR      :   Qualitative Representation
%   trans   :   [optional] transition locations
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-20
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

QR              =   SCS.QR{1}       ; 

[oo,trans]      =   SCSverify_Case2(SCS)        ;   % verify shape

QR(1,2:end)     =   trans           ;
QR(2,1:end-1)   =   trans           ;
QR              =   QR([1:2 4:5],:) ;   % reduce to episode bounds and first and second derivative
QR              =   QR'             ;   % rotate
