function [verified,ListVerified] = SCSverify_Case1(SCS,IntX) 

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - SCSverify_Case1.m
%
% This function executes shape verification.
%
% Syntax:
%   [verified,trans] = SCSverify_Case1(SCS,IntX)
%
% Inputs:
%   SCS     :   Structure describing the Shape Constrained Spline function
%
% Outputs:
%   verified    :   Boolean indicating whether or not all transitions could
%                   be found with absolute precision 
%   ListVerified:   Boolean vector indicating for each transition whether
%                   or not it could be found with absolute precision
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-20
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

J               =   size(IntX,2)    ;

ListVerified    =   false(J,1)      ;
tk              =   SCS.tk        ;
verifiable      =   SCS.verifiable    ;

for j=1:J
    if verifiable(j)
        loc1            =   find(tk(1:end-1)<=IntX(1,j),1,'last')    ;
        loc2            =   find(tk(2:end)>=IntX(2,j),1,'first')    ;
        if ~(isempty(loc1) || isempty(loc2))
            ListVerified(j) =   (loc1 ==loc2)   ;
        end
    end
end

verified    =   all(ListVerified)   ;