
% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - SolveSOCPcvx.m
%
% This script solves the Second Order Cone Program (SOCP) by means of the
% CVX package. 
%
% -------------------------------------------------------------------------
% Latest version: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

Lossfun =   str2func([   func2str(Lossfun)  'cvx' ]);

cvx_begin
    cvx_quiet(true)
    variables   x(nx) ...
                x3_0(m3,1) x3_1(m3,1) x3_2(m3,1) y3_0(m3,1) y3_1(m3,1) y3_2(m3,1) ...
                x2_0(m2,1) x2_1(m2,1) x2_2(m2,1) y2_0(m2,1) ...
                x1_0(m1,1) y1_0(m1,1)  ...
                x0_0(m0,1)
    minimize Lossfun(x,SCS)
    subject to

        % =================================================================
        % INTERVAL FUNCTION/DERIVATIVE INEQUALITIES 
        
        % -----------------------------------------------------------------
        % derivative 3: polynomial coefficients p0
        if m0>=1
            
            % all conditions expressed as linear equalities and
            % inequalities
            A0e * [ x; x0_0 ]   ==  bb0e    ;
            A0i * [ x; x0_0 ]   >=  bb0L    ;   % SOC-2
            
        end
        
        % -----------------------------------------------------------------
        % derivative 2: polynomial coefficients p0..p1
        if m1>=1
            
            % all conditions expressed as linear equalities and
            % inequalities
            A1e * [ x; x1_0; y1_0 ] ==  bb1e    ;
            A1i * [ x; x1_0; y1_0 ] >=  bb1L	;   % SOC-2
            
        end
        
        % -----------------------------------------------------------------
        % derivative 1: polynomial coefficients p0..p2
        if m2>=1
            
            % linear equalities
            A2e * [ x; x2_0; x2_1; x2_2; y2_0 ] ==bb2e ;
            
            % cone on x2 variables = quadratic cone (each)
            x2_0    >=      norms([x2_1 x2_2],2,2)              ;   % SOC-1
            % cone on y2 variables = linear inequality (each)
            A2i* [ x; x2_0; x2_1;x2_2; y2_0 ]    >=      bb2L   ;   % SOC-2
            
        end
        
        % -----------------------------------------------------------------
        % function sign: polynomial coefficients p0..p3
        if m3>=1
            
            % linear equalities
            A3e*[ x; x3_0; x3_1;x3_2; y3_0; y3_1;y3_2 ]==bb3e ;
            
            % cone on x3 and y3 variables = quadratic cone (each)
            x3_0      >=      norms([x3_1 x3_2],2,2)              ;   % SOC-1
            y3_0      >=      norms([y3_1 y3_2],2,2)              ;   % SOC-2
        end
        
        % =================================================================
        % INTERVAL FUNCTION/DERIVATIVE EQUALITIES
        if m0eq>=1
            % derivative 3
            E0*x == e0 ;
        end
        
        if m1eq>=1
            % derivative 2
            E1*x == e1 ;
        end
        
        if m2eq>=1
            % derivative 1
            E2*x == e2 ;
        end
        
        if m3eq>=1
            % function value
            E3*x == e3 ;
        end
        
        % =================================================================
        % POINT-WISE CONSTRAINTS
        Ep*x    ==  ePe  ;
        Ap*x    >=  ePL  ;

cvx_end
