
% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - SolveSOCPmosek.m
%
% This script solves the Second Order Cone Program (SOCP) by means of the
% MOSEK package. 
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-06-18
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

% some internal variables
n0  =   m0      ;
n1  =   2*m1    ;
n2  =   4*m2    ;
n3  =   6*m3    ;

% [m0 m1 m2 m3]
% [n0 n1 n2 n3]

% Obtain the matrix dimensions.
% [ne,nx]   = size(B0y);

% Setup quadratic optimization problem as a conic optimization problem:

B   =   B0y                             ;

clear prob;

Sigma = (B'*B+L);
F = chol(Sigma);
% Finv = F^(-1);
nt =1;
W = SCS.presolve.W{1};
z = SCS.presolve.x{1};
H = W ;
f = -W*z;

F = chol(H) ;
Finv = F^(-1) ;

% making use of transformed t variables, as conic program
clear prob
cones           =   cell(1,1)                   ;
cones{1}.type   =   'MSK_CT_QUAD'               ;
cones{1}.sub    = [ 2*nx+nt    nx+(1:nx)  ]   ;
cc = [ zeros(1,2*nx) 1]' ;
aa  =[F -eye(nx)  zeros(nx,1) ] ;
blc=F*z;
buc=F*z;
prob.a      =   aa    ;
prob.blc    =   blc   ;
prob.buc    =   buc   ;
prob.c      =   cc      ;
prob.cones	=   cones   ;
% [r,res]     =   mosekopt('minimize echo(0)',prob);
% x5          =   res.sol.itr.xx  ;
% xev         =   double(x5) ;
% x5           =   xev(1:nx) ;
ne = nx;


if sum(n0+n1+n2+n3)==0
    clear prob
    
else
    
    clear prob
    
    nv  =   nx+ne+nt+n0+n1+n2+n3        ;
    aa  = [ aa  sparse(ne,n0+n1+n2+n3) ] ;
    
    
    % =================================================================
    % INTERVAL FUNCTION/DERIVATIVE INEQUALITIES
    
    % -----------------------------------------------------------------
    % derivative 3: polynomial coefficients p0
    aa0     =   zeros(2*m0,nv)      ;
    aa0     =   sparse(aa0)         ;
    cc0     =   zeros(n0,1)         ;
    blc0    =   zeros(2*m0,1)   ;
    buc0    =   zeros(2*m0,1)   ;
    if m0>=1
        
        col0        = [ 1:nx    nx+ne+nt+(1:n0) ]   ;
        aa0(:,col0) =   A0                          ;
        
        blc0        = [ bb0e    ;   bb0L        ]   ;
        buc0        = [ bb0e    ;   bb0U        ]   ;
        blc0        =   sparse(blc0)                ;
        buc0        =   sparse(buc0)                ;
        
    end
    
    % -----------------------------------------------------------------
    % derivative 2: polynomial coefficients p0..p1
    aa1     =   zeros(4*m1,nv)      ;
    aa1     =   sparse(aa1)         ;
    cc1     =   zeros(n1,1)         ;
    blc1    =   zeros(1,4*m1)       ;
    buc1    =   zeros(1,4*m1)       ;
    if m1>=1
        
        ref1        =   nx+ne+nt+m0                 ;
        col1        = [ 1:nx    ref1+(1:n1)     ]   ;
        aa1(:,col1) =   A1                          ;
        
        blc1        = [ bb1e    ;   bb1L        ]   ;
        buc1        = [ bb1e    ;   bb1U        ]   ;
        blc1        =   sparse(blc1)                ;
        buc1        =   sparse(buc1)                ;
        
    end
    
    % -----------------------------------------------------------------
    % derivative 1: polynomial coefficients p0..p2
    aa2     =   zeros(4*m2,nv)      ;
    aa2     =   sparse(aa2)         ;
    cc2     =   zeros(n2,1)         ;
    blc2    =   zeros(1,4*m2)       ;
    buc2    =   zeros(1,4*m2)       ;
    cones2  =   cell(m2,1)          ;
    if m2>=1
        
        ref2                =   nx+ne+nt+m0+2*m1        ;
        col2                = [ 1:nx ref2+(1:n2)    ]   ;
        aa2(:,col2)         =   A2                      ;
        
        blc2                = [ bb2e ; bb2L ];
        buc2                = [ bb2e ; bb2U ];
        blc2                =   sparse(blc2);
        buc2                =   sparse(buc2);
        
        for ci = 1:m2
            sub             =  ref2+[ci ci+m2 ci+2*m2] ;
            cones2{ci}.type =   'MSK_CT_QUAD'   ;
            cones2{ci}.sub  =   sub             ;
        end
        
    end
    
    % -----------------------------------------------------------------
    % function sign: polynomial coefficients p0..p3
    aa3     =   zeros(4*m3,nv)  ;
    aa3     =   sparse(aa3)     ;
    cc3     =  	zeros(n3,1) 	;
    blc3    =   zeros(4*m3,1)   ;
    buc3    =   zeros(4*m3,1)   ;
    cones3  =   cell(m3*2,1)    ;
    if m3>=1
        ref3            =   nx+ne+nt+m0+2*m1+4*m2       ;
        col3            = [ 1:nx ref3+(1:n3)        ]   ;
        aa3(:,col3)     =   A3                          ;
        
        blc3            =   bb3e  ;
        buc3            =   bb3e  ;
        blc3            =   sparse(blc3);
        buc3            =   sparse(buc3);
        
        for ci = 1:m3
            for j=1:2
                sub     = ref3+(j-1)*(n3/2)+[ci ci+m3 ci+2*m3];
                cones3{ci+(j-1)*m3}.type = 'MSK_CT_QUAD';
                cones3{ci+(j-1)*m3}.sub  = sub;
            end
        end
    end
    
    %         disp('mosek3')
    % =================================================================
    % INTERVAL FUNCTION/DERIVATIVE EQUALITIES
    E = zeros(0,nx) ;
    e = zeros(0,1)  ;
    if m0eq>=1
        % derivative 3
        E = [E ; E0];
        e = [e;e0];
    end
    
    if m1eq>=1
        % derivative 2
        E = [E ; E1];
        e = [e;e1];
    end
    
    if m2eq>=1
        % derivative 1
        E = [E ; E2];
        e = [e;e2];
    end
    
    if m3eq>=1
        % function value
        E = [E ; E3];
        e = [e ; e3];
    end
    
    %         disp('mosek4')
    % =================================================================
    % POINT-WISE CONSTRAINTS
    E = [E ; Ep ; Ap];
    aa4 = [E zeros(size(E,1),nv-nx) ];
    blc4 = [ e ; ePe; ePL ];
    buc4 = [ e ; ePe; ePU ];
    
    % #################################################################
    % #################################################################
    % #################################################################
    
    % Use of MOSEK:
    
    % =================================================================
    % I. SETUP PROBLEM
    
    %         disp('mosek5')
    % Linear constraints: A*x>=bL  A*x<=bU
    % prob.a      = [ aa   ]; % Matrix A
    % prob.blc    = [ blc  ]; % Vector bL (lower bounds)
    % prob.buc    = [ buc  ]; % Vector bU (upper bounds)
    % size(aa)
    % size(aa0)
    % size(aa2)
    
    %     aa= aa*blkdiag(Finv,eye(nt+n0+n1+n2+n3));
    aa          = [ aa  ;   aa0	;   aa1 ;   aa2 ;   aa3 ;   aa4  ]; % Matrix A
    blc         = [ blc ;   blc0;   blc1;   blc2;   blc3;   blc4 ]; % Vector bL (lower bounds)
    buc         = [ buc ;   buc0;   buc1;   buc2;   buc3;   buc4 ]; % Vector bU (upper bounds)
    cc          = [ cc  ;   cc0 ;   cc1 ;   cc2 ;   cc3 ];
    cones       = [	cones;  cones2; cones3 ]    ;
    
end

prob.a      =   aa    ;
prob.blc    =   blc   ;
prob.buc    =   buc   ;

% Linear coefficients for objective function:
% prob.c      = [ cc   ]';
% size(cc)
% size(cc0)
% size(cc2)
prob.c      =   cc  ;

% Aggregate quadratic cones:
% prob.cones	= [	cones  ]    ;
prob.cones	=   cones   ;

% =================================================================
% II. SOLVE PROBLEM

%     size(prob.a)
%     size(prob.c)
%     size(prob.blc)
%     size(prob.buc)

%         disp('mosek6')
[r,res]     =   mosekopt('minimize echo(0)',prob);
% =================================================================
% III. GET COEFFICIENTS
x           =   res.sol.itr.xx  ;
xev         =   double(x) ;
x           =   xev(1:nx) ;

%  x= Finv*x;

%     figure, plot(x)
%     pause
            