function [int,inteq,m,meq] = SplitInt(int)

% -------------------------------------------------------------------------
% SCS toolbox - SplitInt.m
%
% Split knot interval shape specification into equality constrained
% intervals and inequality constrained intervals 
% new value = sign of original value times max of zero and absolute value
% 
% Syntax is as follows:
%   [int,inteq,m,meq] = SplitInt(int)
%
% Inputs: 	
%   int 	: interval shape specifications
% Outputs: 	
%   int 	: interval shape specifications for inequality constraints
% 	inteq	: interval shape specifications for equality constraints
% 	m		: number of inequality constrained knot intervals
% 	meq		: number of equality constrained knot intervals
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

eq      =   int(:,6)==0         ;   % equality or not
nan     =   isnan(int(:,6))     ;   % not specified

inteq   =   int(eq,:)           ;   % equality intervals
int     =   int(~or(nan,eq),:)  ;   % inequality intervals

meq     =   size(inteq,1)       ;   % number of equality constraints
m       =   size(int,1)         ;   % number of inequality constraints
