
% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - TryCVX.m
%
% This script tests the MOSEK optimization software by trying a small test
% example adapted from the qco1.m example on the CVX website.
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-06-26
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

clc
clear all
close all

if isempty(help('cvx_begin'))
    
    fprintf('\nERROR: Function ''cvx_begin'' was not found. The CVX folder appears not to be in the Matlab path.')
    fprintf('\n')
    
else
    
    try
        m = 20; n = 10; p = 4;
        A = randn(m,n); b = randn(m,1);
        C = randn(p,n); d = randn(p,1); e = rand;
        cvx_begin
            variable x(n)
            minimize( norm( A * x - b, 2 ) )
            subject to
                C * x == d
                norm( x, Inf ) <= e
        cvx_end
        
        % Display the solution.
        fprintf('\nx:');
        fprintf(' %-.4e',x');
        fprintf('\n||x||: %-.4e',norm(x));
        fprintf('\n')
        fprintf('\nSUCCESS: CVX appears installed correctly')
        fprintf('\n')
    catch
        
        fprintf('\nERROR: CVX appears installed incompletely or incorrectly.')
        fprintf('\n')
        
    end
    
    
end
return
