
% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - TryMOSEK.m
%
% This script tests the MOSEK optimization software by trying a small test
% example adapted from the qco1.m example on the MOSEK website.
%
% -------------------------------------------------------------------------
% Last modification: Kris Villez, 2013-06-26
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------

clc
clear all
close all

if isempty(help('mosekopt'))
    
    fprintf('\nERROR: Function ''mosekopt'' was not found. The MOSEK folder appears not to be in the Matlab path.')
    fprintf('\n')
    
else
    
    try
        % qco1.m
        
        clear prob;
        
        % Specify the linear objective terms.
        prob.c = ones(3,1);
        
        % Specify the quadratic objective terms.
        prob.qcsubk = [1 1 1 2 ]';
        prob.qcsubi = [1 2 3 2 ]';
        prob.qcsubj = [1 2 3 2 ]';
        prob.qcval = [2.0 2.0 2.0 0.2]';
        
        % Specify the linear constraint matrix
        prob.a = [sparse(1,3);sparse([1 0 1])];
        
        prob.buc = [1 0.5]';
        
        [r,res] = mosekopt('minimize echo(3)',prob);
        
        % Display the solution.
        fprintf('\nx:');
        fprintf(' %-.4e',res.sol.itr.xx');
        fprintf('\n||x||: %-.4e',norm(res.sol.itr.xx));
        fprintf('\n')
        fprintf('\nSUCCESS: MOSEK appears installed correctly')
        fprintf('\n')
    catch
        
        fprintf('\nERROR: MOSEK appears installed incompletely or incorrectly. License may be missing.')
        fprintf('\n')
        
    end
    
    
end
return
