function y = softcut(x,crit)

% -------------------------------------------------------------------------
% Shape Constrained Splines toolbox - softcut.m
%
% Execute soft tresholding as in wavelet tresholding
% new value = sign of original value times max of zero and absolute value
% minus critical value
%  y = sign(x) .* max(0,abs(x)-crit) 
% 
% Syntax:
%	y = softcut(x,crit)
%
% Inputs: 	
%   x 		: original data series
% 	crit	: critical absolute value
% Outputs: 	
%   y		: soft-tresholded data series
%
% -------------------------------------------------------------------------
% Last version: Kris Villez, 2013-05-14
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Copyright 2012-2013 Kris Villez
%
% This file is part of the SCS Toolbox for Matlab/Octave. 
% 
% The SCS Toolbox is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by the
% Free Software Foundation, either version 3 of the License, or (at your
% option) any later version.
% 
% The SCS Toolbox is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
% Public License for more details.
% 
% You should have received a copy of the GNU General Public License along
% with the SCS Toolbox. If not, see <http://www.gnu.org/licenses/>.  
% -------------------------------------------------------------------------


sx  =   sign(x)                 ;   % sign of value
ax  =   abs(x)                  ;   % absolute value
y   =   sx.*max(0,ax-crit)      ;   % soft tresholded value